@@ -1,35 +1,17 @@
 from __future__ import annotations
 
-import functools
-import itertools
 import pickle
-import random
-import typing as ty
-from abc import ABC, abstractmethod
-from collections import OrderedDict
-from dataclasses import dataclass
-from os import PathLike
 from pathlib import Path
 from typing import (
     Any,
     Callable,
-    Dict,
-    FrozenSet,
     Generic,
-    List,
     Mapping,
     Optional,
-    Sequence,
     Tuple,
-    TypeVar,
-    Union,
 )
 
-import instancelib as il
-import matplotlib.pyplot as plt  # type: ignore
-import numpy as np
 import numpy.typing as npt
-import pandas as pd
 from instancelib.feature_extraction.base import BaseVectorizer
 from instancelib.functions.vectorize import vectorize
 from instancelib.instances.base import Instance
@@ -40,21 +22,12 @@ from ..environment.base import AbstractEnvironment
 from ..environment.memory import MemoryEnvironment
 from ..factory.factory import ObjectFactory
 from ..module.component import Component
-from ..stopcriterion.base import AbstractStopCriterion
 from ..typehints import DT, IT, KT, LT, RT, VT
 from .classificationplotter import ClassificationPlotter
 from .experiments import ClassificationExperiment, ExperimentIterator
 from .initialization import Initializer
-from .plotter import AbstractPlotter, ExperimentPlotter
-
-
-def reset_environment(
-    vectorizer: BaseVectorizer[IT],
-    environment: AbstractEnvironment[IT, KT, DT, npt.NDArray[Any], RT, LT],
-) -> AbstractEnvironment[IT, KT, DT, npt.NDArray[Any], RT, LT]:
-    env = MemoryEnvironment.from_environment_only_data(environment)
-    vectorize(vectorizer, env, True, 200)  # type: ignore
-    return env
+from .tarplotter import TarExperimentPlotter
+import gc
 
 
 def initialize_tar_simulation(
@@ -67,7 +40,7 @@ def initialize_tar_simulation(
     neg_label: LT,
 ) -> Tuple[
     ActiveLearner[IT, KT, DT, npt.NDArray[Any], RT, LT],
-    BaseVectorizer[Instance[KT, DT, npt.NDArray[Any], RT]],
+    Optional[BaseVectorizer[Instance[KT, DT, npt.NDArray[Any], RT]]],
 ]:
     """Build and initialize an Active Learning method.
 
@@ -102,12 +75,15 @@ def initialize_tar_simulation(
     learner_builder: Callable[
         ..., ActiveLearner[IT, KT, DT, npt.NDArray[Any], RT, LT]
     ] = factory.create(Component.ACTIVELEARNER, **al_config)
-    vectorizer: BaseVectorizer[Instance[KT, DT, npt.NDArray[Any], RT]] = factory.create(
-        Component.FEATURE_EXTRACTION, **fe_config
-    )
-
+    if fe_config:
+        vectorizer: BaseVectorizer[
+            Instance[KT, DT, npt.NDArray[Any], RT]
+        ] = factory.create(Component.FEATURE_EXTRACTION, **fe_config)
+        vectorize(vectorizer, env, True, 2000)  # type: ignore
+    else:
+        vectorizer = None  # type: ignore
     ## Copy the data to memory
-    start_env = reset_environment(vectorizer, env)
+    start_env = MemoryEnvironment.from_environment_only_data(env)
 
     # Build the Active Learner object
     learner = learner_builder(start_env, pos_label=pos_label, neg_label=neg_label)
@@ -118,21 +94,28 @@ def initialize_tar_simulation(
 
 
 class TarSimulator(Generic[IT, KT, DT, VT, RT, LT]):
-    plotter: ExperimentPlotter[LT]
+    plotter: TarExperimentPlotter[LT]
     experiment: ExperimentIterator
     output_pkl_path: Optional[Path]
     output_pdf_path: Optional[Path]
     plot_interval: int
+    stop_when_found_all: bool
+    stop_when_satisified: bool
+    current_result: Mapping[str, bool]
+
 
     def __init__(
         self,
         experiment: ExperimentIterator[IT, KT, DT, VT, RT, LT],
-        plotter: ExperimentPlotter[LT],
+        plotter: TarExperimentPlotter[LT],
         max_it: Optional[int] = None,
         print_enabled=False,
         output_path: Optional[Path] = None,
         output_pdf_path: Optional[Path] = None,
         plot_interval: int = 20,
+        plot_enabled=True,
+        stop_when_found_all=False,
+        stop_when_satisfied=False,
     ) -> None:
         self.experiment = experiment
         self.plotter = plotter
@@ -141,6 +124,11 @@ class TarSimulator(Generic[IT, KT, DT, VT, RT, LT]):
         self.output_pkl_path = output_path
         self.output_pdf_path = output_pdf_path
         self.plot_interval = plot_interval
+        self.plot_enabled = plot_enabled
+        
+        self.stop_when_found_all = stop_when_found_all
+        self.stop_when_satisified = stop_when_satisfied
+        self.current_result = {"dummy": False}
 
     @property
     def _debug_finished(self) -> bool:
@@ -148,23 +136,55 @@ class TarSimulator(Generic[IT, KT, DT, VT, RT, LT]):
             return False
         return self.experiment.it > self.max_it
 
+    @property
+    def stop_all_found(self) -> bool:
+        if self.stop_when_found_all:
+            pos_label = self.experiment.pos_label
+            truth_pos = self.experiment.learner.env.truth.get_instances_by_label(
+                pos_label
+            )
+            current_pos = self.experiment.learner.env.truth.get_instances_by_label(
+                pos_label
+            ).intersection(self.experiment.learner.env.labeled)
+            diff = truth_pos.difference(current_pos)
+            return not diff
+        return False
+    
+    @property
+    def criteria_satisified(self) -> bool:
+        if self.stop_when_satisified:
+            return all(self.current_result.values())
+        return False
+
     def simulate(self) -> None:
         with tqdm(total=len(self.experiment.learner.env.dataset)) as pbar:
             pbar.update(self.experiment.learner.len_labeled)
-            while not self.experiment.finished and not self._debug_finished:
-                result = self.experiment()
-                self.plotter.update(self.experiment, result)
-                if self.print_enabled:
-                    self.plotter.print_last_stats()
+            while (
+                not self.experiment.finished
+                and not self._debug_finished
+                and not self.stop_all_found
+                and not self.criteria_satisified
+            ):
+                self.current_result = self.experiment()
+                self.plotter.update(self.experiment, self.current_result)
                 pbar.update(1)
-                if self.output_pkl_path is not None:
-                    with self.output_pkl_path.open("wb") as fh:
-                        pickle.dump(self.plotter, fh)
+                found = self.plotter.recall_stats[self.plotter.it].pos_docs_found
+                estimates = [
+                    f"{n} {e.point:.1f}, CI: [{e.lower_bound:.1f}, {e.upper_bound:.1f}]"
+                    for n, e in self.plotter.estimates[self.plotter.it].items()
+                ]
+                pbar.set_description(f"Found: {found}, Estimate: {estimates}")
                 if (
                     self.experiment.it % self.plot_interval == 0
                     and self.output_pdf_path is not None
                 ):
-                    self.plotter.show(filename=self.output_pdf_path)
+                    if self.output_pkl_path is not None:
+                        with self.output_pkl_path.open("wb") as fh:
+                            pickle.dump(self.plotter, fh)
+                    if self.plot_enabled:
+                        self.plotter.show(filename=self.output_pdf_path)
+                if self.experiment.it % 1000 == 0:
+                    gc.collect()
 
 
 class ClassificationSimulator(Generic[IT, KT, DT, VT, RT, LT]):
