@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from typing import Any, Callable, Generic, Mapping, Optional, Sequence, Tuple, TypeVar
 
 import numpy.typing as npt
-from instancelib.utils.func import flatten_dicts
+from instancelib.utils.func import flatten_dicts, list_unzip
 
 from ..estimation.quant import QuantEstimator
 
@@ -22,11 +22,17 @@ from ..estimation.base import AbstractEstimator
 from ..estimation.catalog import EstimatorCatalog
 from ..estimation.mhmodel import (
     ChaoAlternative,
-    ChaoEstimator,
-    FastChao1989Estimator,
-    FastChaoEstimator,
-    FastChaoNMinEstimator,
+    BiasFallback,
+    BiasCorrectedEstimator,
+    ChaoRivestEstimator,
+    Chao1989Estimator,
+    Chao1987Estimator,
+    ChaoRivestOriginalPoint,
+    NMinWhenAvailable,
     LogLinear,
+    OnlyNMin,
+    BiasFallbackVariance,
+    Chao2006,
 )
 from ..estimation.rasch_comb_parametric import EMRaschRidgeParametricPython
 from ..estimation.rasch_multiple import EMRaschRidgeParametricConvPython
@@ -145,7 +151,7 @@ ESTIMATION_REPOSITORY = {
     EstimationConfiguration.RaschApproxConvParametric: EMRaschRidgeParametricConvPython[
         int, str, npt.NDArray[Any], str, str
     ](),
-    EstimationConfiguration.CHAO: ChaoEstimator[Any, Any, Any, Any, Any, str](),
+    EstimationConfiguration.CHAO: ChaoRivestEstimator[Any, Any, Any, Any, Any, str](),
     EstimationConfiguration.AUTOSTOP: HorvitzThompsonVar1(),
     EstimationConfiguration.LOGLINEAR: LogLinear[Any, Any, Any, Any, Any, str](),
 }
@@ -208,6 +214,28 @@ def conservative_optimistic_builder(
     return builder
 
 
+def combine_builders_long(
+    *builders: Callable[
+        [LT, LT],
+        Tuple[Mapping[str, AbstractEstimator], Mapping[str, AbstractStopCriterion[LT]]],
+    ]
+) -> Callable[
+    [LT, LT],
+    Tuple[Mapping[str, AbstractEstimator], Mapping[str, AbstractStopCriterion[LT]]],
+]:
+    def builder(
+        pos_label: LT, neg_label: LT
+    ) -> Tuple[
+        Mapping[str, AbstractEstimator], Mapping[str, AbstractStopCriterion[LT]]
+    ]:
+        estimators, criteria = list_unzip([bf(pos_label, neg_label) for bf in builders])
+        estimator_dict = flatten_dicts(*estimators)
+        criteria_dict = flatten_dicts(*criteria)
+        return estimator_dict, criteria_dict
+
+    return builder
+
+
 def combine_builders(
     a: Callable[
         [LT, LT],
@@ -296,29 +324,49 @@ def last_seq_builder(
 
 
 STOP_BUILDER_REPOSITORY = {
-    StopBuilderConfiguration.CHAO_CONS_OPT: combine_builders(
+    StopBuilderConfiguration.CHAO_CONS_OPT: combine_builders_long(
         conservative_optimistic_builder(
-            {"ChaoFast1989": FastChao1989Estimator()}, TARGETS
+            {"Chao(Rivest)": ChaoRivestEstimator()}, TARGETS
         ),
-        combine_builders(
-            conservative_optimistic_builder({"Chao": ChaoEstimator()}, TARGETS),
-            conservative_optimistic_builder(
-                {"ChaoFast": FastChaoNMinEstimator()}, TARGETS
-            ),
+        conservative_optimistic_builder(
+            {"Chao(1987)NMIN": NMinWhenAvailable()}, TARGETS
         ),
+        conservative_optimistic_builder({"Chao(1987)": BiasFallback()}, TARGETS),
+        conservative_optimistic_builder(
+            {"Chao(1987)": BiasFallbackVariance()}, TARGETS
+        ),
+        conservative_optimistic_builder(
+            {"Chao(1987)STRICT": Chao1987Estimator()}, TARGETS
+        ),
+        conservative_optimistic_builder(
+            {"Chao(2006)": BiasCorrectedEstimator()}, TARGETS
+        ),
+        conservative_optimistic_builder({"Chao(1989)": Chao1989Estimator()}, TARGETS),
+        conservative_optimistic_builder({"Chao(1987)NMINONLY": OnlyNMin()}, TARGETS),
     ),
     StopBuilderConfiguration.QUANT: conservative_optimistic_builder(
         {"Quant": QuantEstimator(2.0)}, TARGETS
     ),
-    StopBuilderConfiguration.CHAO_CONS_OPT_ALT: conservative_optimistic_builder(
-        {"ChaoALT": ChaoAlternative()}, TARGETS
-    ),
-    StopBuilderConfiguration.CHAO_BOTH: combine_builders(
-        conservative_optimistic_builder({"Chao": ChaoEstimator()}, TARGETS),
-        conservative_optimistic_builder({"ChaoALT": ChaoAlternative()}, TARGETS),
+    StopBuilderConfiguration.CHAO_CONS_OPT_ALT: combine_builders_long(
+        conservative_optimistic_builder(
+            {"Chao(1987)V": BiasFallbackVariance()}, TARGETS
+        ),
+        conservative_optimistic_builder(
+            {"Chao(2006)V": Chao2006()}, TARGETS
+        )),
+    StopBuilderConfiguration.CHAO_BOTH: combine_builders_long(
+        conservative_optimistic_builder(
+            {"Chao(1987)": BiasFallbackVariance()}, TARGETS
+        ),
+        conservative_optimistic_builder(
+            {"Chao(2006)": Chao2006()}, TARGETS
+        ),
+        conservative_optimistic_builder({"Chao(Rivest)": ChaoRivestEstimator()}, TARGETS),
+        conservative_optimistic_builder({"Chao(Rivest)O": ChaoRivestOriginalPoint()}, TARGETS),
+        conservative_optimistic_builder({"Chao(1987)OLD": BiasFallback()}, TARGETS),
     ),
     StopBuilderConfiguration.RCAPTURE_ALL: combine_builders(
-        conservative_optimistic_builder({"Chao": ChaoEstimator()}, TARGETS),
+        conservative_optimistic_builder({"Chao": ChaoRivestEstimator()}, TARGETS),
         conservative_optimistic_builder({"LL": LogLinear()}, TARGETS),
     ),
     StopBuilderConfiguration.AUTOTAR: standoff_builder,
@@ -333,10 +381,10 @@ STOP_BUILDER_REPOSITORY = {
 
 EXPERIMENT_REPOSITORY: Mapping[ExperimentCombination, TarExperimentParameters] = {
     ExperimentCombination.CHAO: TarExperimentParameters(
-        ALConfiguration.CHAO_ENSEMBLE,
+        ALConfiguration.CHAO_IB_ENSEMBLE,
         None,
         SeededEnsembleInitializer.builder(1),
-        (StopBuilderConfiguration.CHAO_CONS_OPT, StopBuilderConfiguration.AUTOTAR),
+        (StopBuilderConfiguration.CHAO_BOTH,),
         10,
         10,
         10,
