@@ -6,6 +6,28 @@ get_abundance <- function(df) {
   res <- dat$CI
   return(as.data.frame(res))
 }
+getval <- function(expr){
+  tryCatch(expr, error=function(e){return(NA)})
+}
+get_abundance_orig_point <- function(df) {
+  dat <- closedpCI.0(df, t = Inf, m = "Mh", h = "LB")
+  point_est <- dat$results[1]
+  infCI <- dat$CI[2]
+  supCI <- dat$CI[3]
+  infoCI <- dat$CI[4]
+  if (is.na(supCI) || supCI >= point_est) {
+    res <- list(abundance = point_est,
+                infCL = infCI,
+                supCL = supCI,
+                infoCI = infoCI)
+  } else {
+    res <- list(abundance = point_est,
+                infCL = point_est,
+                supCL = point_est,
+                infoCI = point_est)
+  }
+  return(as.data.frame(res))
+}
 get_abundance_eta <- function(df) {
   dat <- closedpCI.0(df, m = "Mh", h = "LB")
   res <- dat$CI
