@@ -9,12 +9,16 @@ def test_seed(tmp_path: Path):
     dataset = TarDataset(DatasetType.REVIEW, DATASET, None)
     target_path = tmp_path / "results"
     at, _ = tar_benchmark(dataset, target_path, ExperimentCombination.AUTOTAR, POS, NEG, seed=42, max_it=-1)
+    assert at is not None
     ens, _ = tar_benchmark(dataset, target_path, ExperimentCombination.CHAO_IB, POS, NEG, seed=42, max_it=-1)
+    assert ens is not None
     assert frozenset(at.env.labeled) == frozenset(ens.env.labeled) 
     
 def test_no_seed(tmp_path: Path):
     dataset = TarDataset(DatasetType.REVIEW, DATASET, None)
     target_path = tmp_path / "results"
     at, _ = tar_benchmark(dataset, target_path, ExperimentCombination.AUTOTAR, POS, NEG, seed=None, max_it=-1)
+    assert at is not None
     ens, _ = tar_benchmark(dataset, target_path, ExperimentCombination.CHAO_IB, POS, NEG, seed=None, max_it=-1)
+    assert ens is not None
     assert frozenset(at.env.labeled) != frozenset(ens.env.labeled) 
\ No newline at end of file
